/***********************************************************************************
* 	Exemplo minimalista para uso da UART através de polling
*	Baseado em:
*	--------------------------------------------------------------------------------
*	STR71x Example Application 
*	by Martin Thomas, Kaiserlautern, Germany
*	http://www.siwawi.arubi.uni-kl.de/avr_projects/arm_projects
*
*	Target: STR710 on STR710 eval-board (MB393B)
*	        using the internal flash memory (verify boot-jumpers)
*	Compiler/Toolchain: GNU with gcc 4.1.1 (WinARM 6/06)
*
*	Partly based on code from:
*	- Anglia Design (www.anglia-designs.com, Author: Spencer Oliver)
*	- STMicroelectronics (www.st.com)
*	- Yuri Tiomkin (www.tnkernel.org)
*
*	This demo code and associated components are provided as is and has no warranty,
*	implied or otherwise. You are free to use/modify any of the provided
*	code at your own risk in your applications with the expressed limitation
*	of liability (see below)
* 
*	LIMITATION OF LIABILITY: THE AUTHORS OF THIS EXAMPLE SHALL NOT BE LIABLE FOR ANY
*	LOSS OF PROFITS, LOSS OF USE, LOSS OF DATA, INTERRUPTION OF BUSINESS, NOR FOR
*	INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES OF ANY KIND WHETHER UNDER
*	THIS AGREEMENT OR OTHERWISE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
*
***********************************************************************************/

#include <stdio.h>
#include "71x_lib.h"
#include "vectors.h"

#define UART0_Rx_Pin (0x0001<<8)
#define UART0_Tx_Pin (0x0001<<9)

#define UART1_Rx_Pin (0x0001<<10)
#define UART1_Tx_Pin (0x0001<<11)

#define UART2_Rx_Pin (0x0001<<13)
#define UART2_Tx_Pin (0x0001<<14)

#define UART3_Rx_Pin (0x0001<<1)
#define UART3_Tx_Pin (0x0001<<0)


UART_TypeDef *computer = UART0;
UART_TypeDef *imu = UART1;
UART_TypeDef *altimeter = UART2;
u8 i;

static void my_wait ( int tempo )
{
	volatile int waiting_time ;
	for(waiting_time = 0; waiting_time < tempo; waiting_time++) {} ;
}

void my_InitFreq (void)
{
	// use the PLL and configure the various clocks:
	/* RCCU peripheral configuration ------------------------------------------*/
	RCCU_Div2Config( ENABLE );                    // DIV2
	
	/*  Configure MCLK clock for the CPU, RCCU_DEFAULT = RCLK /1 */
	RCCU_MCLKConfig (RCCU_DEFAULT);  //Main system clock, to ARM & memory
	/*  Configure FCLK = RCLK /2 */
	RCCU_FCLKConfig ( RCCU_RCLK_2 ); //Clock to the fast peripherals
	/*  Configure PCLK = RCLK /4 */
	RCCU_PCLKConfig ( RCCU_RCLK_2 );//Peripheral clock, to APB
		/*  Configure the PLL1 ( * 12 , / 2 ) */
	RCCU_PLL1Config ( RCCU_PLL1_Mul_16, RCCU_Div_1 );	
	/*  Wait PLL to lock */
	while( RCCU_FlagStatus( RCCU_PLL1_LOCK ) == RESET );	
	/*  Select PLL1_Output as RCLK clock */
	RCCU_RCLKSourceConfig (RCCU_PLL1_Output) ;
}

void my_InitIO (void)
{
	// P0.3 as output PP
	GPIO_Config( GPIO0, (1<<3), GPIO_OUT_PP );
	
	// P0.0, P0.1 and P0.2 outputs
	GPIO_Config( GPIO0, (1<<0)|(1<<1)|(1<<2), GPIO_OUT_PP );
	
	// P1.8 and P1.9 as outputs
	//GPIO_Config( GPIO1, (1<<8)|(1<<9), GPIO_IN_TRI_TTL );
	GPIO_Config( GPIO1, (1<<8)|(1<<9), GPIO_OUT_PP );
	
	GPIO_BitWrite( GPIO1, 8, 0x00); //Prepara para receber dados do altimetro
}

void my_InitUART(UART_TypeDef *UARTx, u16 baudrate)
{
	
	if(UARTx == UART0)
	{
		GPIO_Config(GPIO0, UART0_Tx_Pin, GPIO_AF_PP);
		GPIO_Config(GPIO0, UART0_Rx_Pin, GPIO_IN_TRI_CMOS);
	}
	else if(UARTx == UART1)
	{
		GPIO_Config(GPIO0, UART1_Tx_Pin, GPIO_AF_PP);
		GPIO_Config(GPIO0, UART1_Rx_Pin, GPIO_IN_TRI_CMOS);
	}
	else if(UARTx == UART2)
	{
		GPIO_Config(GPIO0, UART2_Tx_Pin, GPIO_AF_PP);
		GPIO_Config(GPIO0, UART2_Rx_Pin, GPIO_IN_TRI_CMOS);
	}
	else if(UARTx == UART3)
	{
		GPIO_Config(GPIO0, UART3_Tx_Pin, GPIO_AF_PP);
		GPIO_Config(GPIO0, UART3_Rx_Pin, GPIO_IN_TRI_CMOS);
	}
	
	/*  Configure the UART X */
	UART_OnOffConfig(UARTx, ENABLE);       /*  Turn UART0 on */
	UART_FifoConfig(UARTx, DISABLE);      /*  Disable FIFOs */
	UART_FifoReset(UARTx, UART_RxFIFO); /*  Reset the UART_RxFIFO */
	UART_FifoReset(UARTx, UART_TxFIFO ); /*  Reset the UART_TxFIFO */
	UART_LoopBackConfig(UARTx , DISABLE);   /*  Disable Loop Back */
	/* Configure the UART0 as following:
	- Baudrate = baudrate 
	- No parity
	- 8 data bits
	- 1 stop bit */
	UART_Config( UARTx, baudrate, UART_NO_PARITY, UART_1_StopBits ,UARTM_8D );
	UART_RxConfig(UARTx ,ENABLE);
}

int main (void)
{
	my_InitFreq();
	my_InitIO();
	
	my_InitUART(imu, 38400);
	my_InitUART(computer, 57600);
	my_InitUART(altimeter, 9600);
	
	EIC_IRQChannelPriorityConfig( UART2_IRQChannel, 1 );
	EIC_IRQChannelConfig( UART2_IRQChannel, ENABLE );
	UART_ItConfig(UART2,UART_RxBufFull, ENABLE );

	EIC_IRQChannelPriorityConfig(UART1_IRQChannel, 7 );
	EIC_IRQChannelConfig( UART1_IRQChannel, ENABLE );
	UART_ItConfig(UART1,UART_RxBufFull, ENABLE );
	
   	EIC_IRQChannelPriorityConfig( UART0_IRQChannel, 5 );
   	EIC_IRQChannelConfig( UART0_IRQChannel, ENABLE );
   	UART_ItConfig(UART0,UART_RxBufFull, ENABLE );
	
	
	
   	EIC_IRQConfig(ENABLE);
	
	while(1)
	{
		for(i = 1; i < 5; i++)
		{
			GPIO_BitWrite( GPIO1, 8, !GPIO_BitRead( GPIO1, 8 ));
			my_wait(100000);
		}
	}
}
